@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '1.03'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '1.04'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -498,7 +498,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.03 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-01.
+This document describes version 1.04 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -704,15 +704,20 @@ L<Perinci::CmdLine::Any>, L<Perinci::CmdLine::Classic>
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.=head1 BUGS
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+
+=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Lite>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
