@@ -1,12 +1,12 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '1.03'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '1.04'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-#use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use PERLANCAR::File::HomeDir qw(get_my_home_dir);
 
@@ -104,12 +104,17 @@ sub get_args_from_config {
             $a cmp $b
         } keys %$conf;
 
+    my %seen_profiles; # for debugging message
     for my $section (@sections) {
         if (defined $profile) {
             if (length $scn) {
-                next unless $section =~ /\A(\Q$scn\E|GLOBAL)\s+\Qprofile=$profile\E\z/;
+                next unless $section =~ /\A(?:(?:\Q$scn\E|GLOBAL)\s+)?profile=(.+)\z/;
+                $seen_profiles{$1}++;
+                next unless $1 eq $profile;
             } else {
-                next unless $section eq "profile=$profile";
+                next unless $section =~ /\Aprofile=(.+)\z/;
+                $seen_profiles{$1}++;
+                next unless $1 eq $profile;
             }
         } else {
             if (length $scn) {
@@ -133,6 +138,8 @@ sub get_args_from_config {
         }
         $found++;
     }
+    $log->tracef("[pericmd] Seen config profiles: %s",
+                 [sort keys %seen_profiles]);
 
     [200, "OK", $args, {'func.found'=>$found}];
 }
@@ -152,7 +159,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.03 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-01.
+This document describes version 1.04 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-02.
 
 =head1 FUNCTIONS
 
@@ -234,15 +241,20 @@ Return value:  (any)
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.=head1 BUGS
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+
+=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Lite>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
