@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '1.03'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '1.04'; # VERSION
 
 use 5.010;
 use strict;
@@ -126,7 +126,7 @@ Test::Perinci::CmdLine - Test library for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.03 of Test::Perinci::CmdLine (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-01.
+This document describes version 1.04 of Test::Perinci::CmdLine (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-02.
 
 =head1 FUNCTIONS
 
@@ -136,15 +136,20 @@ This document describes version 1.03 of Test::Perinci::CmdLine (from Perl distri
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.=head1 BUGS
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+
+=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Lite>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
